Package: munch
Title: Rich Inline Text for 'grid' Graphics and 'flextable'
Version: 0.0.2
Authors@R: c(
    person("David", "Gohel", , "david.gohel@ardata.fr", role = c("aut", "cre")),
    person("ArData", role = "cph")
  )
Description: Renders rich inline text (bold, italic, code, links, images)
    in grid graphics and 'ggplot2', from markdown or 'flextable' chunks.
    Provides grobs, theme elements, and geometry layers for styled text rendering.
    Only works with graphics devices that support 'systemfonts', such as
    those provided by 'ragg', 'svglite', or 'ggiraph'. The 'cairo_pdf'
    device is also supported when fonts are installed at the system level.
License: MIT + file LICENSE
URL: https://ardata-fr.github.io/munch/
BugReports: https://github.com/ardata-fr/munch/issues
Imports: cli, commonmark, flextable, patchwork, gdtools, ggplot2, grid,
        methods, systemfonts, xml2
Suggests: doconv, ggiraph, knitr, magick, ragg, rmarkdown, rsvg,
        svglite, testthat (>= 3.0.0), withr
VignetteBuilder: knitr, rmarkdown
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-09 09:48:14 UTC; davidgohel
Author: David Gohel [aut, cre],
  ArData [cph]
Maintainer: David Gohel <david.gohel@ardata.fr>
Repository: CRAN
Date/Publication: 2026-04-16 09:10:02 UTC
Built: R 4.5.2; ; 2026-04-20 23:44:40 UTC; unix
