# Generated by roxygen2: do not edit by hand

S3method(dim,mdGrob)
S3method(element_grob,element_chunks)
S3method(element_grob,element_md)
S3method(ggplot2::ggplot_add,munch_annotation)
S3method(ggplot2::merge_element,element_chunks)
S3method(ggplot2::merge_element,element_md)
S3method(heightDetails,chunksGrob)
S3method(heightDetails,mdGrob)
S3method(heightDetails,mdTitleGrob)
S3method(makeContent,MdTextAutoWrapGrob)
S3method(makeContent,chunksGrob)
S3method(makeContent,mdGrob)
S3method(makeContent,mdTitleGrob)
S3method(plot,mdGrob)
S3method(print,mdGrob)
S3method(print,text_props)
S3method(widthDetails,chunksGrob)
S3method(widthDetails,mdGrob)
S3method(widthDetails,mdTitleGrob)
export(GeomLabelMd)
export(GeomTextMd)
export(as_paragraph_md)
export(chunks_grob)
export(default_text_props)
export(element_chunks)
export(element_md)
export(geom_label_md)
export(geom_text_md)
export(md_grob)
export(munch_annotation)
importFrom(flextable,chunk_dataframe)
importFrom(flextable,get_flextable_defaults)
importFrom(gdtools,strings_sizes)
importFrom(ggplot2,element_grob)
importFrom(ggplot2,ggplot_add)
importFrom(grid,convertHeight)
importFrom(grid,convertWidth)
importFrom(grid,gList)
importFrom(grid,gTree)
importFrom(grid,gpar)
importFrom(grid,grid.draw)
importFrom(grid,grid.layout)
importFrom(grid,grid.newpage)
importFrom(grid,heightDetails)
importFrom(grid,makeContent)
importFrom(grid,makeContext)
importFrom(grid,nullGrob)
importFrom(grid,popViewport)
importFrom(grid,pushViewport)
importFrom(grid,rasterGrob)
importFrom(grid,rectGrob)
importFrom(grid,setChildren)
importFrom(grid,textGrob)
importFrom(grid,unit)
importFrom(grid,unit.c)
importFrom(grid,viewport)
importFrom(grid,vpStack)
importFrom(grid,widthDetails)
importFrom(methods,slot)
importFrom(patchwork,plot_annotation)
importFrom(systemfonts,font_info)
